from setuptools import setup

setup(name = 'tim124_distributions',
      version = '0.1',
      description = 'Gaussian and Binomial distributions',
      packages = ['tim124_distributions'],
      author = "Tim Chan",
      author_email = "timchansdp@gmail.com",
      zip_safe=False)
